#
# spec file for package webalizer
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define editlvl 08

Name:           webalizer
Summary:        A Web Server Log File Analysis Program
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Utilities
Version:        2.23
Release:        bp155.3.12
URL:            http://www.mrunix.net/webalizer/
Source0:        ftp://ftp.mrunix.net/pub/webalizer/%{name}-%{version}-%{editlvl}-src.tar.bz2
Source1:        flags.tar.bz2
Source2:        flags.license.html
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch0:         %{name}-2.21-02.diff
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch1:         %{name}-2.21-02-ia64.diff
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch3:         %{name}-2.21-02-maxagent.diff
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch4:         %{name}-2.23-04-conf.patch
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch5:         %{name}-2.21-02-fclose.diff
# FIX-DATADIR - fix for datadir and mandir
Patch6:         %{name}-2.23-04-Makefile.patch
Patch7:         webalizer-overlinking.patch
# static variables
Patch8:         webalizer-static.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  db-devel
BuildRequires:  gd-devel
BuildRequires:  libapr-util1-devel
BuildRequires:  libbz2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  pcre-devel
Requires:       %{name}-flags

%description
Webalizer is a web server log file analysis program which produces
usage statistics in HTML format for viewing with a browser.  The
results are presented in both columnar and graphical formats, which
facilitates interpretation.  Yearly, monthly, daily, and hourly usage
statistics are presented, along with the ability to display usage by
site, URL, referrer, user agent (browser) and country (user agent and
referrer are only available if your web server produces Combined log
format files).

Webalizer supports CLF (common log format) log files, as well as
Combined log formats as defined by NCSA and others, and variations of
these which it attempts to handle intelligently.

%package flags
Summary:        Flags of the World
License:        CC-BY-SA-3.0
Group:          Productivity/Networking/Web/Utilities
URL:            http://flags.blogpotato.de/
BuildArch:      noarch

%description flags
Images for those who want to visualize the data returned by an
IP-to-Country database (e.g. the one provided by Directi) with
corresponding flags. Flags provided are based on the iso3166
countrycode, that means there are currently 243 flags offered in the
world set.

%prep
%setup -q -n %{name}-%{version}-%{editlvl} -a 1
%patch0
%patch1
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8 -p1
%{__cp} -a %{S:2} .

%build
autoconf
CFLAGS="%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64" ./configure \
  --prefix=%{_prefix} \
  --mandir=%{_mandir} \
  --sysconfdir=%{_sysconfdir} \
  --enable-bz2 \
  --enable-geoip \
  --with-gdlib=%{_libdir} \
  --with-gd=/usr/include/gd \
  %{_target_cpu}-suse-linux
make LIBNAME=%{_lib}

%install
install -d -m 755 %{buildroot}%{_prefix}/bin
install -d -m 755 %{buildroot}/etc
install -d -m 755 %{buildroot}/%{_mandir}/man1
make "DESTDIR=%{buildroot}" install
install -d -m 755 %{buildroot}%{apache_serverroot}/htdocs/%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name}
mv %{buildroot}/%{_sysconfdir}/%{name}.conf.sample %{buildroot}/%{_sysconfdir}/%{name}.conf

#install flags
%{__cp} -a flags %{buildroot}%{apache_serverroot}/htdocs/%{name}/

%preun
#rm -f var/lib/%{name}/*

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc CHANGES COPYING Copyright README README.FIRST country-codes.txt
%doc %{_mandir}/man?/*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %{apache_serverroot}/htdocs/%{name}
%exclude %{apache_serverroot}/htdocs/%{name}/flags
%{_bindir}/*
%{_localstatedir}/lib/%{name}

%files flags
%defattr(-,root,root)
%doc flags.license.html
%dir %{apache_serverroot}/htdocs/%{name}/flags
%{apache_serverroot}/htdocs/%{name}/flags/*

%changelog
* Tue Dec  1 2020 pgajdos@suse.com
- use system apache rpm macros
* Mon Jun  8 2020 pgajdos@suse.com
- fix build
- added patches
  fix static variables
  + webalizer-static.patch
* Fri Nov  8 2019 pgajdos@suse.com
- remove GeoIP support [bsc#1156197]
* Thu Apr 27 2017 chris@computersalat.de
- update flags pkg
  * add missing EU flag (from special flags)
  * noarch pkg
  * remove deps to webalizer -> webalizer requires flags
* Thu Mar 26 2015 dimstar@opensuse.org
- Drop mm BuildRequires: unneeded dependency (that no longer is
  satisfied in Tumbleweed).
* Sun Oct 19 2014 crrodriguez@opensuse.org
- webalizer-overlinking.patch: Remove use of xorg-x11-devel
  its need was the product of overlinking. X libraries are
  never directly used.
* Thu Nov 14 2013 chris@computersalat.de
- update to update to 2.23-08
  * Fix sporadic eol problem with some IIS/W3C logs
  * Fix compiler directive syntax error (broke some 64 bit systems)
  - Changes/Additions:
  * Modest speed improvements in hash table code
- rebase patches
- fix spec
  * package flags too, not only the DIR
* Thu Jun 21 2012 chris@computersalat.de
- add missing Group to subpkg
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu May 12 2011 chris@computersalat.de
- update to 2.23-05
  o several fixes for catalan lang
* Sun Mar 20 2011 chris@computersalat.de
- add world flags (sub-pkg)
  o add missing link for uk.png
  o add missing su.png
  o add license file (CC BY-SA 3.0)
    http://creativecommons.org/licenses/by-sa/3.0/legalcode
- rework configuration patch > conf patch
  o fix path to GeoIP.dat
* Sat Mar 19 2011 chris@computersalat.de
- update to 2.23
  o Fix sporadic eol problem with some IIS/W3C logs
  o Fix compiler directive syntax error (broke some 64 bit systems)
  o Modest speed improvements in hash table code
  - for further changes please see CHANGES file
- fix License: GPLv2+
- spec-cleaner
- remove obsolete define patch
- add Makefile patch
  o fix for data-/mandir
- remove Obsoletes/Provides webalize
- remove author from spec
- preun: do not remove var/lib/webalizer/*
* Wed Sep  1 2010 anicka@suse.cz
- fix build with zlib
- enable geoip (bnc#635762)
* Thu May 27 2010 anicka@suse.cz
- enable bzip2 (bnc#606239)
* Mon Sep  7 2009 anicka@suse.cz
- fixed resource leak (bnc#531678)
* Sun Apr 19 2009 crrodriguez@suse.de
- remove db1-devel buildrequire, not used anymore
* Mon Mar  9 2009 anicka@suse.cz
- update to 2.20
  * Added missing memory deallocation call in DNS lookup code.
  * Minor fixes to configure script
  * Added "YearTotals" config option for main index page totals
* Mon Jul 28 2008 anicka@suse.cz
- update to 2.20
  * Fixed problem with timing totals.
  * Fixed referrer linking to avoid possible xss injection.
  * Fixed month change detection error that caused incorrect report
  dates when logs had a 'gap' longer than a year.
  * Fixed buffer overrun possibility in parsing code and user agent
  mangle logic.
  * Added symbolic link checks for file I/O to prevent possible
  privilege escalation exploits.  Disallows reading from or writing
  to any file that is a symlink.  Thanks to Julien Danjou.
  * Added code to preserve the history and incremental data files in
  the event of a crash before writing to them completely.  Thanks
  to Robert Millan for the idea and initial code.
  * Added native geolocation services, which fully supports both IPv4
  and IPv6 lookups.  Adds the configuration keywords 'GeoDB' and
  'GeoDBDatabase' along with the '-j' and '-J' command line options.
  * Added 'wcmgr', "The Webalizer (DNS) Cache file Manager" to the
  distribution to provide cache file maintenance.  See the supplied
  man page for a description and usage information.
  * Changed history code and main index page to allow for more than
  12 months of reports to be displayed.  Added the config keywords
  'IndexMonths' (-K command line option), 'GraphMonths' (-k command
  line option) and 'YearHeaders' to control how index is displayed.
  * Changed Berkeley DB code to use current 4.x APIs.
  * Added support for bzip2 compressed log files (.bz2) as a compile
  time option (--enable-bz2).  If enabled, bzipped files will be
  decompressed automatically during processing.
  * Added support for W3C formatted logs.  Based on code submitted
  by Klaus Reimer.
  * Added GeoIP support as compile time option (--enable-geoip). Adds
  'GeoIP' and 'GeoIPDatabase' config keywords, '-w' and '-W'
  command line options. (http://www.maxmind.com/)
  * Added IPv6 support.  Based on initial code by Jose Carlos Meneiros
  and modified to support Solaris and other problematic platforms.
  * Added 'CacheIPs' config option to allow saving unresolved addresses
  in the DNS cache.
  * Added 'CacheTTL' config option which allows the DNS cache time to
  live (TTL) value to be specified at run-time.
  * Added 'SearchCaseI' config option to specify if search strings
  should be treated as case insensitive or not.  The default value,
  'yes', causes search strings to be treated as case insensitive.
  * Added 'HTAccess' config option.  Allows writing a default .htaccess
  file to the output directory.
  * Added ability to display flags in the top country table.  Adds the
  config keywords 'CountryFlags' and 'FlagDir', and -z command line
  option.
  * Added 'StripCGI' config option to configure how CGI variables on
  the end of URLs are treated (can now be stripped or left in place).
  * Added 'DefaultIndex' config option to enable/disable the use of
  "index." as a default index name to be stripped from the end of URLs.
  * Added 'TrimSquidURL' config option to allow squid log URLs to be
  reduced in granularity by a user definable amount.  Thanks to code
  submitted by Stuart Gall.
  * Added 'OmitPage' config option (and the '-O' command line switch)
  to prevent specified URLs from being counted as pages even if they
  otherwise would be.  Thanks to code submitted by Adam Morton.
  * Added 'IgnoreState' config option (and the -b command line switch)
  to allow ignoring any existing incremental data file (similar to
  the IgnoreHist/-i option).
  * Changed logic to always generate summary report (index.html),
  even if no records were processed.
  * Added color support to allow changing graph colors.  Based on the
  Webalizer-usecolor code submitted by Benoit Rouits.  Adds 11 new
  config options, see the README file for complete descriptions.
  * Added language 'lang=' specification in generated HTML files.
  * Added 'LinkReferrer' config option to allow/disallow links in the
  top referrers table.
  * Added 'PagePrefix' config option to allow URL prefix matches to
  be counted as pages, regardless of file extension or type.  Thanks
  to code submitted by Remco Van de Meent.
  * Enabled large file support (LFS) to support logs greater than 2Gb
  in size on systems that support LFS.  Also increased the size of
  most internal counters to handle larger sites.
  * Minor changes to generated HTML output
  * Updated language files country codes for current IANA TLDs
  * Changed the meaning of the -v command line switch.  It now
  causes verbose information to be displayed at run-time
  (Informational and Debug messages).
  * Changed Group* config options to allow a quoted string for
  the match string.  This allows spaces to be embedded in the
  string.
  * Changed log record parsing logic to allow spaces in URLs.
  * Made configuration keywords, boolean configuration values
  (yes/no), and log file types case insensitive.  Also fixed
  defaults for invalid values to reflect documented defaults.
  * Changed configure script to use --sysconfdir to specify the
  location of the default webalizer.conf configuration file.
  Also added support for DESTDIR during install to aid binary
  package builds.
- remove ipv6 and overflow patches
* Mon Mar 12 2007 anicka@suse.cz
- fix processing IPv6 addresses [#219403]
* Fri Dec  8 2006 anicka@suse.cz
- add IPv6 patch from Arkadiusz Miskiewicz [#219403]
* Thu Mar 16 2006 anicka@suse.cz
- change LogFile to /var/log/apache2/access_log (#157931)
- create separate patch with configuration changes
* Tue Mar 14 2006 anicka@suse.cz
- change OutputDir to /srv/www/htdocs/webalizer (#157932)
* Fri Feb 10 2006 anicka@suse.cz
- fix array subscript out of range (#135607)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon May 23 2005 mjancar@suse.cz
- increase MAXAGENT (#84040)
* Thu Apr 21 2005 tcrhak@suse.de
- added db1 and db1-devel to neededforbuild
  in order to enable DNS lookup (bug #59003)
* Mon May 10 2004 hmacht@suse.de
- building as non-root user
- changed command apxs2 to /usr/sbin/apxs2
  Mo Mai 10 18:00:37 CEST 2004
* Sun Apr 18 2004 ro@suse.de
- build with apache2
* Thu Jan  9 2003 tcrhak@suse.cz
- added LFS support
* Sun Dec 22 2002 tcrhak@suse.cz
- update to version 2.01-10
- buffer overflow security fix (patch overflow)
* Thu Aug  1 2002 ro@suse.de
- adapt server root
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 31 2002 tcrhak@suse.cz
- fixed security patch (don't break search strings at chars
  with ascii > 127
- used macros %%{_libdir} and %%{_lib}
* Tue Oct 30 2001 tcrhak@suse.cz
- update to 2.01-9 (includes sec-fix.patch)
* Wed Jul 18 2001 adostal@suse.cz
- fixed neededforbuild
- clear requires
* Wed Jun  6 2001 schwab@suse.de
- Remove stupid casts.
* Wed May 23 2001 cihlar@suse.cz
- fixed cast warnings on ia64
* Wed Mar 21 2001 ro@suse.de
- added freetype2 to neededforbuild
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Thu Nov 16 2000 cihlar@suse.cz
- renamed webalize -> webalizer
- update to version 2.01-6
- fixed neededforbuild
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild gdlib -> gd gd-devel
* Thu Oct  5 2000 cihlar@suse.cz
- update to version 2.01.03
* Tue Aug 29 2000 cihlar@suse.cz
- fixed webalize.conf
- bzipped sources
* Wed Apr 26 2000 cihlar@suse.cz
- added BuildRoot
* Thu Apr 13 2000 ro@suse.de
- added mm to neededforbuild
* Mon Mar 13 2000 grimmer@suse.de
- fixed path to Apache logfiles (have been moved to
  /var/log/httpd for SuSE Linux 6.4)
* Wed Jan 26 2000 grimmer@suse.de
- specfile updates (added URL, Group)
- Now uses macro for man page locations
* Mon Oct 11 1999 ro@suse.de
- converted to use png with gdlib 1.7.3
* Sat Oct  2 1999 grimmer@suse.de
- Update to 1.30-04
- Specfile cleanups
- added docu
* Mon Sep 20 1999 ro@suse.de
- added requires http_daemon
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue May  4 1999 grimmer@suse.de
- Update to 1.22-03
- corrected sample configuration comment
- specfile tweaks for new version
* Thu Apr 29 1999 grimmer@suse.de
- corrected typo in config-file
* Tue Oct  6 1998 grimmer@suse.de
- new version 1.20-07
- specfile cleanup
* Thu Feb 12 1998 ro@suse.de
- new package by bb for web server log file analysis
